@@ -144,8 +144,6 @@ typedef struct siminf_thread_args
     const double *ldata; /**< Matrix (Nld X Nn). ldata(:,j) gives a
                           *   local data vector for node #j. */
     const double *gdata; /**< The global data vector. */
-    const int *sd;    /**< Each node can be assigned to a
-                       *   sub-domain. */
     const int *N;     /**< Shift matrix for internal and external
                        *   transfer events. */
     int *update_node; /**< Vector of length Nn used to indicate nodes
@@ -571,8 +569,7 @@ static int siminf_solver()
                                         &sa.v[node * sa.Nd],
                                         &sa.ldata[node * sa.Nld],
                                         sa.gdata,
-                                        sa.tt,
-                                        sa.sd[node]);
+                                        sa.tt);
 
                     sa.sum_t_rate[node] += sa.t_rate[node * sa.Nt + j];
                 }
@@ -631,8 +628,7 @@ static int siminf_solver()
                                           &sa.v[node * sa.Nd],
                                           &sa.ldata[node * sa.Nld],
                                           sa.gdata,
-                                          sa.t_time[node],
-                                          sa.sd[node])) - old;
+                                          sa.t_time[node])) - old;
                         }
                         sa.sum_t_rate[node] += delta;
 
@@ -793,7 +789,7 @@ static int siminf_solver()
                     const int rc = sa.pts_fun(
                         &sa.v_new[node * sa.Nd], &sa.u[node * sa.Nc],
                         &sa.v[node * sa.Nd], &sa.ldata[node * sa.Nld],
-                        sa.gdata, sa.Ni + node, sa.tt, sa.sd[node]);
+                        sa.gdata, sa.Ni + node, sa.tt, sa.rng);
 
                     if (rc < 0) {
                         sa.errcode = rc;
@@ -810,7 +806,7 @@ static int siminf_solver()
                                           &sa.u[node * sa.Nc],
                                           &sa.v_new[node * sa.Nd],
                                           &sa.ldata[node * sa.Nld],
-                                          sa.gdata, sa.tt, sa.sd[node])) - old;
+                                          sa.gdata, sa.tt)) - old;
                         }
                         sa.sum_t_rate[node] += delta;
 
@@ -910,8 +906,6 @@ static int siminf_solver()
  * @param ldata Double matrix (Nld X Nn). Generalized data matrix,
  *        data(:,j) gives a local data vector for node #j.
  * @param gdata The global data vector.
- * @param sd Integer vector of length Nn. Each node can be assigned to
- *        a sub-domain.
  * @param Nn Number of nodes.
  * @param Nc Number of compartments in each node.
  * @param Nt Total number of different transitions.
@@ -948,7 +942,7 @@ int siminf_run_solver(
     const int *u0, const double *v0, const int *irG, const int *jcG,
     const int *irS, const int *jcS, const int *prS, const double *tspan,
     int tlen, int *U, double *V, const double *ldata, const double *gdata,
-    const int *sd, int Nn, int Nc, int Nt, int Nd, int Nld, const int *irE,
+    int Nn, int Nc, int Nt, int Nd, int Nld, const int *irE,
     const int *jcE, const int *N, int len, const int *event,
     const int *time, const int *node, const int *dest, const int *n,
     const double *proportion, const int *select, const int *shift,
@@ -1057,7 +1051,6 @@ int siminf_run_solver(
         sim_args[i].v_new = &vv_2[sim_args[i].Ni * Nd];
         sim_args[i].ldata = &ldata[sim_args[i].Ni * sim_args[i].Nld];
         sim_args[i].gdata = gdata;
-        sim_args[i].sd = &sd[sim_args[i].Ni];
         sim_args[i].update_node = &update_node[sim_args[i].Ni];
 
         /* Scheduled events */
