@@ -72,38 +72,111 @@ stopifnot(length(grep("Invalid 'min_dist' argument. Please provide 'min_dist' >
 
 ## Check 'data' argument to C function 'siminf_ldata_sp'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", NULL, d, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", NULL, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", d, d, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", d, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", 1:10, d, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", 1:10, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
 ## Check 'distance' argument to C function 'siminf_ldata_sp'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, NULL, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", l, NULL, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'distance' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, l, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", l, l, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'distance' argument",
                       res[[1]]$message)) > 0)
 
+res <- tools::assertError(
+    .Call("siminf_ldata_sp", l, Matrix::Diagonal(10), 0L, PACKAGE = "SimInf"))
+stopifnot(length(grep("Invalid 'distance' argument",
+                      res[[1]]$message)) > 0)
+
+## Check 'metric' argument to C function 'siminf_ldata_sp'
+res <- tools::assertError(
+    .Call("siminf_ldata_sp", l, d, NA_integer_, PACKAGE = "SimInf"))
+stopifnot(length(grep("Invalid 'metric' argument",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+    .Call("siminf_ldata_sp", l, d, NULL, PACKAGE = "SimInf"))
+stopifnot(length(grep("Invalid 'metric' argument",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+    .Call("siminf_ldata_sp", l, d, 0.0, PACKAGE = "SimInf"))
+stopifnot(length(grep("Invalid 'metric' argument",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+    .Call("siminf_ldata_sp", l, d, c(0L, 0L), PACKAGE = "SimInf"))
+stopifnot(length(grep("Invalid 'metric' argument",
+                      res[[1]]$message)) > 0)
+
 ## Check non-equal number of nodes in 'distance' and 'data'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l[, -1], d, PACKAGE = "SimInf"))
+    .Call("siminf_ldata_sp", l[, -1], d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("The number of nodes in 'data' and 'distance' are not equal",
                       res[[1]]$message)) > 0)
 
-## Check 'ldata'
+## Check 'ldata' with metric equal to degree
+ldata_exp <- structure(c(91, 182, 273, 365, 1, 3, 2, 4, -1, 0, 0, 0, 0, 0,
+                         91, 182, 273, 365, 0, 2, 2, 4, 3, 4, -1, 0, 0, 0,
+                         91, 182, 273, 365, 0, 2, 1, 3, 3, 4, 4, 4, -1, 0,
+                         91, 182, 273, 365, 1, 3, 2, 4, 4, 4, 5, 4, -1, 0,
+                         91, 182, 273, 365, 2, 4, 3, 4, 5, 4, 6, 4, -1, 0,
+                         91, 182, 273, 365, 3, 4, 4, 4, 6, 4, 7, 4, -1, 0,
+                         91, 182, 273, 365, 4, 4, 5, 4, 7, 4, 8, 3, -1, 0,
+                         91, 182, 273, 365, 5, 4, 6, 4, 8, 3, 9, 2, -1, 0,
+                         91, 182, 273, 365, 6, 4, 7, 4, 9, 2, -1, 0, 0, 0,
+                         91, 182, 273, 365, 7, 4, 8, 3, -1, 0, 0, 0, 0, 0),
+                       .Dim = c(14L, 10L))
+ldata_obs <- .Call("siminf_ldata_sp", l, d, 0L, PACKAGE = "SimInf")
+stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
+
+## Check 'ldata' with metric equal to distance
+ldata_exp <- structure(c(91, 182, 273, 365, 1, 1.4142135623731,
+                         2, 2.82842712474619, -1, 0, 0, 0, 0, 0,
+                         91, 182, 273, 365, 0, 1.4142135623731, 2,
+                         1.4142135623731, 3, 2.82842712474619, -1, 0, 0, 0,
+                         91, 182, 273, 365, 0, 2.82842712474619, 1,
+                         1.4142135623731, 3, 1.4142135623731,
+                         4, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 1, 2.82842712474619,
+                         2, 1.4142135623731, 4, 1.4142135623731,
+                         5, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 2, 2.82842712474619,
+                         3, 1.4142135623731, 5, 1.4142135623731,
+                         6, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 3, 2.82842712474619,
+                         4, 1.4142135623731, 6, 1.4142135623731,
+                         7, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 4, 2.82842712474619,
+                         5, 1.4142135623731, 7, 1.4142135623731,
+                         8, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 5, 2.82842712474619,
+                         6, 1.4142135623731, 8, 1.4142135623731,
+                         9, 2.82842712474619, -1, 0,
+                         91, 182, 273, 365, 6, 2.82842712474619,
+                         7, 1.4142135623731, 9, 1.4142135623731,
+                         -1, 0, 0, 0,
+                         91, 182, 273, 365, 7, 2.82842712474619,
+                         8, 1.4142135623731, -1, 0, 0, 0, 0, 0),
+                       .Dim = c(14L, 10L))
+ldata_obs <- .Call("siminf_ldata_sp", l, d, 1L, PACKAGE = "SimInf")
+stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
+
+## Check 'ldata' with metric equal to 1 / distance^2
 ldata_exp <- structure(c(91, 182, 273, 365, 1, 0.499999999999996, 2, 0.125,
                          -1, 0, 0, 0, 0, 0, 91, 182, 273, 365, 0,
                          0.499999999999996, 2, 0.499999999999996, 3, 0.125,
@@ -124,7 +197,7 @@ ldata_exp <- structure(c(91, 182, 273, 365, 1, 0.499999999999996, 2, 0.125,
                          0, 91, 182, 273, 365, 7, 0.125, 8, 0.499999999999996,
                          -1, 0, 0, 0, 0, 0), .Dim = c(14L, 10L))
 
-ldata_obs <- .Call("siminf_ldata_sp", l, d, PACKAGE = "SimInf")
+ldata_obs <- .Call("siminf_ldata_sp", l, d, 2L, PACKAGE = "SimInf")
 stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
 
 ## Check identical coordinates
