@@ -78,7 +78,7 @@ sis_e <- SISe(u0      = data.frame(S = 100, I = 0),
               end_t4  = 365,
               epsilon = 0.000011)
 
-sis_e <- run(sis_e)
+sis_e <- run(sis_e, threads = 1)
 sis_e_phi_obs <- sis_e@V[1,]
 stopifnot(all(abs(sis_e_phi_obs - phi_exp) < tol))
 
@@ -106,6 +106,6 @@ sis_e3 <- SISe3(u0      = data.frame(S_1 = 10, I_1 = 0,
                 end_t4    = 365,
                 epsilon   = 0.000011)
 
-sis_e3 <- run(sis_e3)
+sis_e3 <- run(sis_e3, threads = 1)
 sis_e3_phi_obs <- sis_e3@V[1,]
 stopifnot(all(abs(sis_e3_phi_obs - phi_exp) < tol))
