@@ -389,7 +389,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -400,7 +399,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -465,7 +463,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -476,7 +473,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -541,7 +537,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -552,7 +547,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -618,7 +612,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -629,7 +622,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
