@@ -56,7 +56,6 @@ stopifnot(identical(sum(result@U), 1001L))
 stopifnot(any(result@U[1,]))
 stopifnot(any(result@U[2,]))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -69,7 +68,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(any(result_omp@U[1,]))
     stopifnot(any(result_omp@U[2,]))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -134,7 +132,6 @@ stopifnot(all(apply(result@U[1:6,], 1, any)))
 stopifnot(identical(sum(result@U[1:6,11]), 45L))
 stopifnot(identical(sum(result@U[,1]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -147,7 +144,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(sum(result_omp@U[1:6,11]), 45L))
     stopifnot(identical(sum(result_omp@U[,1]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -219,7 +215,6 @@ stopifnot(identical(
               .Dim = c(1L, 11L))))
 stopifnot(identical(sum(result@U[,1]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -238,7 +233,6 @@ if (SimInf:::have_openmp()) {
                   .Dim = c(1L, 11L))))
     stopifnot(identical(sum(result_omp@U[,1]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -289,7 +283,6 @@ stopifnot(all(result@U[1:6,] == 0))
 stopifnot(all(apply(result@U[seq(from=8, to=36, by=2),], 1, any)))
 stopifnot(identical(sum(result@U[,11]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -302,7 +295,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(all(apply(result_omp@U[seq(from=8, to=36, by=2),], 1, any)))
     stopifnot(identical(sum(result_omp@U[,11]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -392,7 +384,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -403,7 +394,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -492,7 +482,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -503,7 +492,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -592,7 +580,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -603,7 +590,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -693,7 +679,6 @@ stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(result@U, U))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -704,7 +689,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -754,7 +738,6 @@ stopifnot(identical(model@S, result@S))
 stopifnot(identical(sum(result@U[1:6,]), 0L))
 stopifnot(all(apply(result@U[7:36,], 1, any)))
 stopifnot(identical(model@ldata, result@ldata))
-stopifnot(identical(model@sd, result@sd))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
@@ -766,7 +749,6 @@ if (SimInf:::have_openmp()) {
     stopifnot(identical(sum(result_omp@U[1:6,]), 0L))
     stopifnot(all(apply(result_omp@U[7:36,], 1, any)))
     stopifnot(identical(model@ldata, result_omp@ldata))
-    stopifnot(identical(model@sd, result_omp@sd))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
@@ -923,6 +905,6 @@ res <- tools::assertError(SimInf:::siminf_error(-10))
 stopifnot(length(grep("Invalid model",
                       res[[1]]$message)) > 0)
 
-res <- tools::assertError(SimInf:::siminf_error(-11))
+res <- tools::assertError(SimInf:::siminf_error(-9000))
 stopifnot(length(grep("Unknown error code",
                       res[[1]]$message)) > 0)
